import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

export const columns: BasicColumn[] = [
  {
    title: '工序编码',
    dataIndex: 'OPER_CODE',
  },
  {
    title: '工序名称',
    dataIndex: 'OPER_NAME',
  },
  {
    title: '是否回流',
    dataIndex: 'IS_REFLOW',
    customRender: ({ record }) => {
      const status = record.IS_REFLOW;
      const enable = status === 'Y';
      const color = enable ? 'green' : 'red';
      const text = enable ? '回流' : '不回流';
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '是否计算直通率',
    dataIndex: 'IS_FPY',
    customRender: ({ record }) => {
      const status = record.IS_FPY;
      const enable = status === 'Y';
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '工序行为',
    dataIndex: 'OPER_ACTION',
    customRender: ({ record }) => {
      const status = record.OPER_ACTION;
      let text = '';
      switch (status) {
        case '1':
          text = '行为一';
          break;
        case '2':
          text = '行为二';
          break;
        case '3':
          text = '打印';
          break;
        case '4':
          text = '存储过程';
          break;
      }
      return text;
    },
  },
  {
    title: '工序类型',
    dataIndex: 'OPER_TYPE',
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'REMARK',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'OPER_CODE',
    label: '工序编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'OPER_NAME',
    label: '工序名称',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'OPER_CODE',
    label: '工序编码',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'OPER_NAME',
    label: '工序名称',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'IS_REFLOW',
    label: '是否回流',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'IS_FPY',
    label: '是否计算直通率',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'OPER_ACTION',
    label: '工序行为',
    required: true,
    component: 'Select',
    colProps: { span: 16 },
    componentProps: {
      options: [
        {
          label: '行为一',
          value: '1',
          key: '1',
        },
        {
          label: '行为二',
          value: '2',
          key: '2',
        },
        {
          label: '打印',
          value: '3',
          key: '3',
        },
        {
          label: '存储过程',
          value: '4',
          key: '4',
        },
      ],
    },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
];
